-- ----------------------------
-- 用户信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user`;
CREATE TABLE mortals_xhx_user(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '用户ID，主键，自增长',
    `loginName` varchar(50)      COMMENT '登录名',
    `loginPwd` varchar(128)      COMMENT '登录密码，使用md5双次加密',
    `loginLimitAddress` varchar(200)      COMMENT '登录限制地址，多个IP地址用逗号分隔，可以使用IP段匹配，如：172.17.*非空：则只能该值内的IP可以登录',
    `realName` varchar(50)      COMMENT '用户名',
    `mobile` varchar(21)      COMMENT '用户手机号',
    `phone` varchar(21)      COMMENT '用户联系电话',
    `email` varchar(50)      COMMENT '用户邮箱',
    `qq` varchar(20)      COMMENT 'QQ号码',
    `userType` tinyint(2)      COMMENT '用户类型，0：系统用户 1:普通用户 2:工作人员，默认2',
    `status` tinyint(2)    DEFAULT '1'  COMMENT '用户状态，0：停用，1：正常，2：冻结，3：销户，4：离职，默认1',
    `customerId` bigint(20)      COMMENT '客户ID',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createUserName` varchar(50)      COMMENT '创建用户名称',
    `lastLoginTime` datetime      COMMENT '最后一次登录时间',
    `lastLoginAddress` varchar(21)      COMMENT '最后一次登录地址',
    `deptId` bigint(20)      COMMENT '用户所属部门id',
    `deptName` varchar(512)      COMMENT '所属部门名称',
    `siteIds` varchar(512)      COMMENT '所属站点id,多个逗号分隔',
    `areaCodes` varchar(512)      COMMENT '所属区域code,多个逗号分隔',
    `staffId` bigint(20)      COMMENT '员工Id，关联用户员工表',
    `openId` varchar(64)      COMMENT '微信openId',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户信息业务';
-- ----------------------------
-- 公司表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_company`;
CREATE TABLE mortals_xhx_company(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `companyName` varchar(128) NOT NULL     COMMENT '公司名称',
    `companyCode` varchar(64)      COMMENT '公司编码',
    `registrationNumber` varchar(64)      COMMENT '注册号',
    `legalRepresentative` varchar(32)      COMMENT '法定代表人',
    `registeredCapital` varchar(128)      COMMENT '注册资本',
    `companyType` varchar(128)      COMMENT '公司类型',
    `businessScope` varchar(128)      COMMENT '经营范围',
    `businessAdress` varchar(128)      COMMENT '经营地址',
    `location` varchar(128)      COMMENT '所在地',
    `areaCode` varchar(128) NOT NULL     COMMENT '所属区域编码',
    `areaName` varchar(128) NOT NULL     COMMENT '所属区域名称',
    `contactPhone` varchar(32) NOT NULL     COMMENT '联系电话',
    `email` varchar(32)      COMMENT '电子邮件地址',
    `website` varchar(64)      COMMENT '公司网站',
    `taxRegistrationNumber` varchar(128)      COMMENT '税务登记号',
    `socialCreditCode` varchar(64)      COMMENT '社会信用代码',
    `trademarkInfo` varchar(64)      COMMENT '商标信息',
    `websiteRegistrationInfo` varchar(64)      COMMENT '网站历史备案信息',
    `totalEmployees` tinyint(4)      COMMENT '员工总数',
    `softNum` tinyint(4)      COMMENT '软件著作权数量',
    `patentNum` tinyint(4)      COMMENT '专利数量',
    `hisDevelop` text      COMMENT '历史发展',
    `lon` varchar(32) NOT NULL     COMMENT '经度',
    `lati` varchar(32) NOT NULL     COMMENT '纬度',
    `logoPath` varchar(128) NOT NULL     COMMENT '企业logo',
    `companyVideoPath` varchar(512)      COMMENT '企业视频',
    `companyPicPath` varchar(512)      COMMENT '企业宣传图片',
    `companyIntroduction` mediumtext      COMMENT '公司介绍',
    `companyCulture` mediumtext      COMMENT '公司文化',
    `sort` int(4)    DEFAULT '0'  COMMENT '排序',
    `establishDate` datetime NOT NULL     COMMENT '成立日期',
    `remark` varchar(64)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='公司';
-- ----------------------------
-- 标注表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_labels`;
CREATE TABLE mortals_xhx_labels(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `labelName` varchar(128) NOT NULL     COMMENT '标签名称',
    `labelDesc` varchar(64)      COMMENT '标签描述',
    `labelLogoPath` varchar(64)      COMMENT '标签图标',
    `sort` int(4)    DEFAULT '0'  COMMENT '排序',
    `remark` varchar(64)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='标注';
-- ----------------------------
-- 公司标注表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_company_labels`;
CREATE TABLE mortals_xhx_company_labels(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `labelId` bigint(20) NOT NULL     COMMENT '标签Id',
    `labelName` varchar(64)      COMMENT '公司名称',
    `companyId` bigint(20) NOT NULL     COMMENT '公司Id',
    `companyName` varchar(64)      COMMENT '公司名称',
    `remark` varchar(64)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='公司标注';

-- ----------------------------
-- 公司专利表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_company_patent`;
CREATE TABLE mortals_xhx_company_patent(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `companyId` bigint(20) NOT NULL     COMMENT '公司Id',
    `intellectPropertyType` varchar(64)      COMMENT '知识产权类型',
    `intellectPropertyNum` int(9)      COMMENT '知识产权数量',
    `remark` varchar(64)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
    `companyName` varchar(64)      COMMENT '公司名称',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='公司专利';

-- ----------------------------
-- 分类表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_category`;
CREATE TABLE mortals_xhx_category(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `name` varchar(64)      COMMENT '分类名称',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='分类';
-- ----------------------------
-- 产品分类表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_product_category`;
CREATE TABLE mortals_sys_product_category(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `productId` bigint(20)      COMMENT '产品id',
    `categoryId` bigint(20)      COMMENT '分类id',
    `productName` varchar(64)      COMMENT '产品名称',
    `categoryName` varchar(64)      COMMENT '分类名称',
    `remark` varchar(64)      COMMENT '备注',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='产品分类';
-- ----------------------------
-- 产品表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_product`;
CREATE TABLE mortals_xhx_product(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `productName` varchar(20) NOT NULL     COMMENT '产品名称，名称唯一',
    `productCode` varchar(256)      COMMENT '产品编码',
    `productSlogan` varchar(64) NOT NULL     COMMENT '产品slogan',
    `productLogoPath` varchar(64) NOT NULL     COMMENT '产品图标',
    `productFacePath` varchar(64) NOT NULL     COMMENT '产品封面图片',
    `productVideoPath` varchar(512)      COMMENT '产品视频,多个视频逗号分割',
    `productPicPath` varchar(512)      COMMENT '产品宣传图片,多个视频逗号分割',
    `productIntroduction` mediumtext      COMMENT '产品介绍',
    `productDetail` mediumtext      COMMENT '产品详情',
    `publishTime` datetime NOT NULL     COMMENT '发布时间',
    `hot` tinyint(1)    DEFAULT '0'  COMMENT '是否热门(0.否,1.是)',
    `productRemark` varchar(256)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='产品';
-- ----------------------------
-- 产品常见问题表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_product_question`;
CREATE TABLE mortals_xhx_product_question(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
    `productId` bigint(20) NOT NULL     COMMENT '产品id',
    `productName` varchar(1024)      COMMENT '产品名称',
    `question` varchar(512)      COMMENT '问题',
    `answer` varchar(2048)      COMMENT '常见问题回答',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='产品常见问题';
-- ----------------------------
-- 员工基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff`;
CREATE TABLE mortals_xhx_staff(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `name` varchar(64) NOT NULL     COMMENT '员工姓名',
    `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
    `birthday` datetime      COMMENT '出生日期',
    `photoPath` varchar(255)      COMMENT '照片',
    `email` varchar(128)      COMMENT '邮件地址',
    `phoneNumber` varchar(128) NOT NULL     COMMENT '联系电话',
    `idCard` varchar(128)      COMMENT '身份证号码',
    `workNum` varchar(128)      COMMENT '工号',
    `companyIds` varchar(128) NOT NULL     COMMENT '所属公司',
    `companyName` varchar(128)      COMMENT '所属公司名称',
    `positionId` bigint(20)      COMMENT '职位ID',
    `positionName` varchar(128)      COMMENT '职位名称',
    `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型（1.全职,2.兼职,3.实习)',
    `staffStatus` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
    `source` tinyint(2)    DEFAULT '1'  COMMENT '员工来源(1.企业内部,2.外部人员)',
    `registerPath` varchar(255)      COMMENT '入职登记表',
    `entryDate` datetime      COMMENT '入职时间',
    `regularDate` datetime      COMMENT '转正时间',
    `leaveDate` datetime      COMMENT '离职时间',
    `remark` varchar(255)      COMMENT '备注',
    `sumViews` int(4)    DEFAULT '0'  COMMENT '累计查看次数',
    `viewsByDay` int(4)    DEFAULT '0'  COMMENT '当日查看次数',
    `sendBusinessCardTimes` int(4)    DEFAULT '0'  COMMENT '发送名片次数',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工基本信息';
-- ----------------------------
-- 职位信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_position`;
CREATE TABLE mortals_xhx_position(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
    `groupId` bigint(20)      COMMENT '分组id',
    `groupName` varchar(128)      COMMENT '分组名称',
    `positionCode` varchar(128)      COMMENT '职位编码',
    `positionName` varchar(128)      COMMENT '职位名称',
    `type` tinyint(2)    DEFAULT '1'  COMMENT '节点类型(1.分组,2.职位)',
    `remark` varchar(512)      COMMENT '备注',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='职位信息';
-- ----------------------------
-- 客户访问记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_record`;
CREATE TABLE mortals_xhx_staff_record(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `staffId` bigint(20)      COMMENT '被查看员工ID',
    `staffName` varchar(64) NOT NULL     COMMENT '被查看员工姓名',
    `viewName` varchar(64) NOT NULL     COMMENT '查看人名称',
    `sumViews` int(4)    DEFAULT '0'  COMMENT '累计查看次数',
    `viewContent` varchar(128)      COMMENT '访问内容',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='客户访问记录信息';
-- ----------------------------
-- 新闻频道分类表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_news_category`;
CREATE TABLE mortals_xhx_news_category(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `name` varchar(64)      COMMENT '频道名称',
    `remark` varchar(64)      COMMENT '备注',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='新闻频道分类';
-- ----------------------------
-- 新闻表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_news`;
CREATE TABLE mortals_xhx_news(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `categoryId` bigint(20)      COMMENT '分类id',
    `categoryName` varchar(128)      COMMENT '分类名称',
    `title` varchar(512) NOT NULL     COMMENT '标题',
    `titleLogoPath` varchar(512) NOT NULL     COMMENT '标题logo',
    `content` mediumtext      COMMENT '内容',
    `top` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '置顶 (0.否，1.是)',
    `viewNums` tinyint(4) NOT NULL   DEFAULT '0'  COMMENT '浏览次数',
    `publishTime` datetime NOT NULL     COMMENT '发布时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
    `editor` varchar(64) NOT NULL     COMMENT '责任编辑',
    `shareNums` tinyint(4) NOT NULL   DEFAULT '0'  COMMENT '分享次数',
    `deptId` bigint(20)      COMMENT '发布部门',
    `deptName` varchar(128)      COMMENT '所属部门名称',
    `statement` varchar(255)      COMMENT '声明',
    `source` varchar(255)      COMMENT '文章来源',
    `remark` varchar(255)      COMMENT '备注',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='新闻';

-- ----------------------------
-- 新闻访问记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_news_record`;
CREATE TABLE mortals_xhx_news_record(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `newsId` bigint(20)      COMMENT '新闻ID',
    `viewName` varchar(64) NOT NULL     COMMENT '查看人名称',
    `sumViews` int(4)    DEFAULT '0'  COMMENT '累计查看次数',
    `remark` varchar(255)      COMMENT '备注',
    `viewTime` datetime NOT NULL     COMMENT '最后浏览时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='新闻访问记录信息';
-- ----------------------------
-- 新闻分享记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_news_share`;
CREATE TABLE mortals_xhx_news_share(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `newsId` bigint(20)      COMMENT '新闻ID',
    `shareName` varchar(64) NOT NULL     COMMENT '分享人名称',
    `sumShares` int(4)    DEFAULT '0'  COMMENT '累计分享次数',
    `remark` varchar(255)      COMMENT '备注',
    `shareTime` datetime NOT NULL     COMMENT '最近分享时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='新闻分享记录信息';

-- ----------------------------
-- 反馈信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_feedback`;
CREATE TABLE mortals_xhx_feedback(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `title` varchar(512) NOT NULL     COMMENT '标题',
    `content` mediumtext      COMMENT '内容',
    `isShow` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '是否公开 (0.否，1.是)',
    `feedbackName` varchar(64) NOT NULL     COMMENT '反馈人姓名',
    `companyName` varchar(64) NOT NULL     COMMENT '单位名称',
    `contactInfo` varchar(64) NOT NULL     COMMENT '联系方式',
    `idCard` varchar(64) NOT NULL     COMMENT '身份证号',
    `address` varchar(64) NOT NULL     COMMENT '地址',
    `email` varchar(64) NOT NULL     COMMENT '邮箱地址',
    `reply` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '是否回复 (0.否，1.是)',
    `replyPerson` varchar(64) NOT NULL     COMMENT '回复人',
    `replyContent` varchar(64) NOT NULL     COMMENT '回复',
    `deptId` bigint(20)      COMMENT '所属部门',
    `deptName` varchar(128)      COMMENT '所属部门名称',
    `feedbackType` tinyint(2) NOT NULL   DEFAULT '1'  COMMENT '反馈类型 (1.建议,2.问题,3.表扬)',
    `fileName` varchar(64) NOT NULL     COMMENT '附件名称，多个逗号分割',
    `filePath` varchar(128)      COMMENT '附件地址，多个逗号分割',
    `replyFileName` varchar(64) NOT NULL     COMMENT '回复附件名称，多个逗号分割',
    `replyFilePath` varchar(128)      COMMENT '回复附件地址，多个逗号分割',
    `replyTime` datetime      COMMENT '回复时间',
    `processId` bigint(20)      COMMENT '处理人id',
    `processName` varchar(64)      COMMENT '处理人名称',
    `processStatus` tinyint(1)    DEFAULT '1'  COMMENT '处理状态(1.未处理,2.已处理)',
    `processComments` varchar(64)      COMMENT '处理意见',
    `processTime` datetime      COMMENT '处理时间',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='反馈信息';






-- ----------------------------
-- 公司产品表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_company_product`;
CREATE TABLE mortals_xhx_company_product(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `companyId` bigint(20) NOT NULL     COMMENT '公司Id',
    `companyName` varchar(64)      COMMENT '公司名称',
    `productId` bigint(20) NOT NULL     COMMENT '产品Id',
    `productName` varchar(64)      COMMENT '产品名称',
    `remark` varchar(64)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='公司产品';



-- ----------------------------
-- 页面信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_page`;
CREATE TABLE mortals_xhx_page(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `pageName` varchar(64) NOT NULL     COMMENT '页面名称',
    `pageType` tinyint(2)      COMMENT '页面类型(1.首页,2.产品详情,3.文章详情)',
    `pageUrl` varchar(64) NOT NULL     COMMENT '页面短链接',
    `otherDetail` varchar(2048)      COMMENT '可以是一个包含其他页面信息的JSON对象或单独的字段，根据页面的具体需求来设计',
    `remark` varchar(255)      COMMENT '备注',
    `favoriteTime` datetime NOT NULL     COMMENT '收藏时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='页面信息';
-- ----------------------------
-- 收藏页面表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_favorites_pages`;
CREATE TABLE mortals_xhx_favorites_pages(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `userId` bigint(20) NOT NULL     COMMENT '用户ID,',
    `pageId` bigint(20) NOT NULL     COMMENT '页面ID, 关联到用户表中的ID，表示哪个用户收藏了这个页面',
    `remark` varchar(255)      COMMENT '备注',
    `favoriteTime` datetime NOT NULL     COMMENT '收藏时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='收藏页面';
-- ----------------------------
-- 收藏产品表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_favorites_product`;
CREATE TABLE mortals_xhx_favorites_product(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `userId` bigint(20) NOT NULL     COMMENT '用户ID,',
    `productId` bigint(20) NOT NULL     COMMENT '产品ID, 关联到产品表中的ID，表示这是哪个产品的收藏',
    `remark` varchar(255)      COMMENT '备注',
    `favoriteTime` datetime NOT NULL     COMMENT '收藏时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='收藏产品';
-- ----------------------------
-- 收藏新闻表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_favorites_news`;
CREATE TABLE mortals_xhx_favorites_news(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `userId` bigint(20) NOT NULL     COMMENT '用户ID,',
    `newsId` bigint(20) NOT NULL     COMMENT '新闻ID, 关联到新闻表中的ID，表示这是哪个新闻的收藏',
    `remark` varchar(255)      COMMENT '备注',
    `favoriteTime` datetime NOT NULL     COMMENT '收藏时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='收藏新闻';
-- ----------------------------
-- 收藏名片表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_favorites_businesscard`;
CREATE TABLE mortals_xhx_favorites_businesscard(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `userId` bigint(20) NOT NULL     COMMENT '用户ID,',
    `staffId` bigint(20) NOT NULL     COMMENT '员工ID, 关联到员工表中的ID，表示这是哪个名片的收藏',
    `remark` varchar(255)      COMMENT '备注',
    `favoriteTime` datetime NOT NULL     COMMENT '收藏时间',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='收藏名片';


-- ----------------------------
-- 名片基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_bussinesscard`;
CREATE TABLE mortals_xhx_bussinesscard
(
    `id`           bigint(20) AUTO_INCREMENT COMMENT '序号，主键，自增长',
    `staffId`      bigint(20) NOT NULL COMMENT '名片所属关联员工ID',
    `staffName`    varchar(64) COMMENT '名片所属关联员工姓名',
    `name`         varchar(64) NOT NULL COMMENT '名片姓名',
    `gender`       tinyint(2) DEFAULT '1' COMMENT '性别(1.男,2.女)',
    `birthday`     datetime COMMENT '出生日期',
    `photoPath`    varchar(255) COMMENT '照片',
    `email`        varchar(128) COMMENT '邮件地址',
    `phoneNumber`  varchar(128) COMMENT '联系电话',
    `idCard`       varchar(128) COMMENT '身份证号码',
    `companyId`    varchar(128) COMMENT '记录名片持有者所在公司或组织的名称ID',
    `companyName`  varchar(128) COMMENT '记录名片持有者所在公司或组织的名称',
    `positionId`   bigint(20) COMMENT '职位ID',
    `positionName` varchar(128) COMMENT '职位名称',
    `bio`          varchar(512) COMMENT '简介',
    `socialMedia`  varchar(512) COMMENT '社交媒体链接, 可以是一个包含社交媒体账号的JSON对象或单独的字段',
    `qRCode`       varchar(512) COMMENT '二维码图片, 可以是一个图片链接或存储路径',
    `remark`       varchar(255) COMMENT '备注',
    `sumViews`     int(4) DEFAULT '0' COMMENT '累计查看次数',
    `viewsByDay`   int(4) DEFAULT '0' COMMENT '当日查看次数',
    `createUserId` bigint(20) COMMENT '创建用户',
    `createTime`   datetime COMMENT '创建时间',
    `updateUserId` bigint(20) COMMENT '更新用户',
    `updateTime`   datetime COMMENT '更新时间',
    PRIMARY KEY (`id`),
    KEY            `name` (`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='名片基本信息';
