package com.mortals.xhx.module.product.web;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.module.category.model.CategoryQuery;
import com.mortals.xhx.module.category.service.CategoryService;
import com.mortals.xhx.module.company.model.CompanyProductQuery;
import com.mortals.xhx.module.company.model.CompanyQuery;
import com.mortals.xhx.module.company.service.CompanyProductService;
import com.mortals.xhx.module.company.service.CompanyService;
import com.mortals.xhx.module.product.model.ProductCategoryQuery;
import com.mortals.xhx.module.product.service.ProductCategoryService;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.product.model.ProductEntity;
import com.mortals.xhx.module.product.service.ProductService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;

import java.util.Arrays;

import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import static com.mortals.framework.ap.SysConstains.*;

/**
 * 产品
 *
 * @author zxfei
 * @date 2023-09-18
 */
@RestController
@RequestMapping("product")
public class ProductController extends BaseCRUDJsonBodyMappingController<ProductService, ProductEntity, Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private ProductCategoryService productCategoryService;
    @Autowired
    private CategoryService categoryService;
    @Autowired
    private CompanyService companyService;

    @Autowired
    private CompanyProductService companyProductService;

    public ProductController() {
        super.setModuleDesc("产品");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "hot", YesNoEnum.getEnumMap());
        this.addDict(model, "categoryId", categoryService.find(new CategoryQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getName(), (o, n) -> n)));
        this.addDict(model, "companyId", companyService.find(new CompanyQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getCompanyName(), (o, n) -> n)));
        super.init(model, context);
    }

    @Override
    protected int editAfter(Long id, Map<String, Object> model, ProductEntity entity, Context context) throws AppException {
        String categoryIds = productCategoryService.find(new ProductCategoryQuery().productId(entity.getId())).stream().map(i -> i.getCategoryId().toString()).collect(Collectors.joining(","));
        String companyIds = companyProductService.find(new CompanyProductQuery().productId(entity.getId())).stream().map(i -> i.getCompanyId().toString()).collect(Collectors.joining(","));

        if (!ObjectUtils.isEmpty(categoryIds)) {
            entity.setCategoryId(categoryIds);
        }
        if (!ObjectUtils.isEmpty(companyIds)) {
            entity.setCompanyId(companyIds);
        }
        return super.editAfter(id, model, entity, context);
    }
}