package com.mortals.xhx.module.staff.web;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.base.system.user.model.UserQuery;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.module.area.model.AreaTreeSelect;
import com.mortals.xhx.module.company.model.CompanyEntity;
import com.mortals.xhx.module.company.model.CompanyQuery;
import com.mortals.xhx.module.company.service.CompanyService;
import com.mortals.xhx.module.position.model.PositionEntity;
import com.mortals.xhx.module.position.model.PositionQuery;
import com.mortals.xhx.module.position.service.PositionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.staff.model.StaffEntity;
import com.mortals.xhx.module.staff.service.StaffService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;

import java.util.Arrays;

import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import static com.mortals.framework.ap.SysConstains.*;

/**
 * 员工基本信息
 *
 * @author zxfei
 * @date 2023-09-18
 */
@RestController
@RequestMapping("staff")
public class StaffController extends BaseCRUDJsonBodyMappingController<StaffService, StaffEntity, Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private CompanyService companyService;
    @Autowired
    private PositionService positionService;
    @Autowired
    private UserService userService;


    public StaffController() {
        super.setModuleDesc("员工基本信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "gender", paramService.getParamBySecondOrganize("Staff", "gender"));
        this.addDict(model, "staffType", paramService.getParamBySecondOrganize("Staff", "staffType"));
        this.addDict(model, "staffStatus", paramService.getParamBySecondOrganize("Staff", "staffStatus"));
        this.addDict(model, "source", paramService.getParamBySecondOrganize("Staff", "source"));

        this.addDict(model, "companyIds", companyService.find(new CompanyQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getCompanyName(), (o, n) -> n)));
        this.addDict(model, "positionId", positionService.find(new PositionQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getPositionName(), (o, n) -> n)));

        this.addDict(model, "updateUserId", userService.find(new UserQuery()).stream().collect(Collectors.toMap(x -> x.getId().toString(), y -> y.getRealName(), (o, n) -> n)));

        super.init(model, context);
    }

    @Override
    protected void saveBefore(StaffEntity entity, Map<String, Object> model, Context context) throws AppException {
        super.saveBefore(entity, model, context);

        if(!ObjectUtils.isEmpty(entity.getCompanyIds())){
            String companyName = Arrays.asList(entity.getCompanyIds().split(",")).stream().map(item -> {
                CompanyEntity companyEntity = companyService.get(Long.parseLong(item), context);
                return companyEntity.getCompanyName();
            }).collect(Collectors.joining(","));
            entity.setCompanyName(companyName);
        }
        if(!ObjectUtils.isEmpty(entity.getPositionId())){
            PositionEntity positionEntity = positionService.get(entity.getPositionId(), getContext());
            entity.setPositionName(positionEntity.getPositionName());
        }
    }



    /**
     * 员工离职
     */
    @PostMapping(value = "leave")
    public String leave(@RequestBody StaffEntity staff) {
        JSONObject ret = new JSONObject();
        Map<String, Object> model = new HashMap<>();
        String busiDesc = "查询" + this.getModuleDesc() + "员工离职";
        try {
            Rest<Void> rest = this.service.leave(staff, getContext());
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            ret.put(KEY_RESULT_MSG,"员工离职成功！");

            recordSysLog(request, busiDesc + "【成功】");
        } catch (Exception e) {
            log.error("离职", e);
            this.doException(request, busiDesc, model, e);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, e.getMessage());
        }
        return ret.toJSONString();
    }
}